# Overview
Mimetica is a software package for analysing microCT scans. It can load a stack of scans and compute the radial and phase density profiles of each layer. The results can also be exported to CSV for further analysis. Mimetica was written in Python using PySide6 as the GUI framework.

# Installation

Create a new Python environment and run

```bash
pip install mimetica
```

After that, you can launch the program from the terminal:

```bash
mimetica
```
